@@ -1,5 +1,6 @@
 import json
 import uuid
+import base64
 from .agent_config import AgentConfig
 from .agent_signature import AgentSignature
 from .types import AgentMessageType
@@ -8,8 +9,8 @@ from .types import AgentMessageType
 class AgentIdentity:
     def __init__(self, config: AgentConfig):
         self.config = config
-        self.private_key = config.keys['privateKey'].encode('utf-8')
-        self.public_key = config.keys['publicKey'].encode('utf-8')
+        self.private_key = base64.b64decode(config.keys['privateKey'])
+        self.public_key = config.keys['publicKey']
 
     @classmethod
     def create(cls, config: AgentConfig):
@@ -21,10 +22,10 @@ class AgentIdentity:
     def name(self) -> str:
         return self.config.name
         
-    def get_public_key_b64(self) -> str:
-        return self.public_key.decode('utf-8')
+    def get_public_key(self) -> str:
+        return self.public_key
 
-    def _create_message(
+    async def _create_message(
         self,
         to_agent_id: str,
         msg_type: AgentMessageType,
@@ -37,20 +38,11 @@ class AgentIdentity:
             "data": data,
         }
         
-        # Pydantic models need to be converted to dicts for JSON serialization
-        # but here `data` is already a dict.
-        # We need a stable JSON representation for signing.
-        message_json = json.dumps(
-            message_without_sig,
-            sort_keys=True, 
-            separators=(',', ':')
-        ).encode('utf-8')
-        
-        signature = AgentSignature.sign(message_json, self.private_key)
+        signature = await AgentSignature.sign(message_without_sig, self.private_key)
         
         return {**message_without_sig, "sig": signature}
 
-    def createTaskRequest(
+    async def createTaskRequest(
         self,
         to_agent_id: str,
         capability: str,
@@ -62,13 +54,13 @@ class AgentIdentity:
             "capability": capability,
             "params": params,
         }
-        return self._create_message(
+        return await self._create_message(
             to_agent_id,
             AgentMessageType.TASK_REQUEST,
             data,
         )
 
-    def createTaskResult(
+    async def createTaskResult(
         self,
         to_agent_id: str,
         task_id: str,
@@ -79,13 +71,13 @@ class AgentIdentity:
             "status": "completed",
             "result": result,
         }
-        return self._create_message(
+        return await self._create_message(
             to_agent_id,
             AgentMessageType.TASK_RESULT,
             data,
         )
 
-    def createTaskError(
+    async def createTaskError(
         self,
         to_agent_id: str,
         task_id: str,
@@ -99,27 +91,20 @@ class AgentIdentity:
             "message": message,
             "retry": retry,
         }
-        return self._create_message(
+        return await self._create_message(
             to_agent_id,
             AgentMessageType.TASK_ERROR,
             data,
         )
 
-    def verify_message(
+    async def verify_message(
         self, message: dict, public_key: bytes,
     ) -> bool:
         message_copy = message.copy()
         signature = message_copy.pop("sig")
 
-        message_json = (
-            json.dumps(
-                message_copy,
-                sort_keys=True,
-                separators=(',', ':'),
-            ).encode('utf-8')
-        )
-        return AgentSignature.verify(
-            message_json,
+        return await AgentSignature.verify(
+            message_copy,
             signature,
             public_key,
         )
